@@ -20,6 +20,7 @@
 	IBOutlet NSTextField *iTunesItemCountField;
   IBOutlet NSTableView *iTunesTable;
 	IBOutlet NSBox *iTunesBox;
+  IBOutlet NSWindow *windowMain;
 }
 - (void)loadTracks;
 - (NJBTransactionResult *)downloadTrackList;
@@ -31,5 +32,7 @@
 - (void)addTrackToiTunes:(Track *)track;
 - (IBAction)searchiTunesTableAction:(id)sender;
 - (void)setCorrectView;
+- (IBAction)uploadAlbumArt:(id)sender;
+- (void)uploadAlbumArtPanelDidEnd:(NSOpenPanel *)openPanel returnCode:(int)returnCode contextInfo:(void *)x;
 
 @end
