@@ -772,7 +772,10 @@ StatusDisplayer *statusDisplayerGlobal;
 		[track setItemID:trackmeta->item_id];
     
     if (createAlbumFiles)
-      [self addTrack:track ToAlbumWithName:[track album]];
+    {
+      Album *album = [self addTrack:track ToAlbumWithName:[track album]];
+      [self uploadAlbumArt:[track image] forAlbum:album];
+    }
 		
 		 LIBMTP_destroy_track_t(trackmeta);
 	}
@@ -817,6 +820,56 @@ StatusDisplayer *statusDisplayerGlobal;
       NSLog(errorString);
       return [[[NJBTransactionResult alloc] initWithSuccess:NO resultString:error extendedErrorString:errorString] autorelease];
 		}
+    
+    // delete from album
+    if (![[track album] isEqualToString:@""])
+    {
+      if (albums == nil)
+        [self downloadAlbumList];
+        
+      Album *album;
+      NSEnumerator *albumEnumerator = [albums objectEnumerator];
+  
+      while (album = [albumEnumerator nextObject])
+      {
+        if ([[album name] caseInsensitiveCompare:[track album]] == NSOrderedSame)
+          break;
+      }
+      
+      if (album != nil)
+      {
+        NSLog(@"deleting track from album");
+        
+        [album deleteTrackWithID:[track itemID]];
+        if ([album trackCount] == 0)
+        {
+          NSLog(@"deleting empty album with id %d", [album albumID]);
+          // delete empty albums
+          if (LIBMTP_Delete_Object(device, [album albumID]) != 0)
+          {
+            NSString *error = @"error deleting album file";
+            NSLog(error);
+            NSString *errorString = [self njbErrorString];
+            NSLog(errorString);
+          }
+          [albums removeObject:album];
+        }
+        else
+        {
+          LIBMTP_album_t *libmtpAlbum = [album toLIBMTPAlbum:track];
+          
+          if (LIBMTP_Update_Album(device, libmtpAlbum) != 0)
+          {
+            NSLog(@"Could not update album");
+            NSString *errorString = [self njbErrorString];
+            NSLog(errorString);
+          }
+          
+          LIBMTP_destroy_album_t(libmtpAlbum);
+        }
+      }
+    }
+  
 	}
 	
 	[self updateDiskSpace];
@@ -975,6 +1028,11 @@ StatusDisplayer *statusDisplayerGlobal;
       return [[[NJBTransactionResult alloc] initWithSuccess:NO resultString:error extendedErrorString:errorString] autorelease];
 		}
 		LIBMTP_destroy_track_t(libmtp_track);
+    
+    if (createAlbumFiles && [newTrack image])
+    {
+      [self uploadAlbumArtForTrack:newTrack];
+    }
 	}
 	
 	[self updateDiskSpace];
@@ -2131,21 +2189,7 @@ int mtp_progress(uint64_t const sent, uint64_t const total, void const * const d
     }
   }
   
-  
-  NSArray *tracks = [album tracks];
-  uint32_t size = [tracks count];
-  uint32_t *trackArray = (uint32_t*)malloc(sizeof(uint32_t)*size);
-  uint32_t i = 0;
-  for (i = 0; i < size; i++)
-    trackArray[i] = [[tracks objectAtIndex:i] itemID];
-		
-  LIBMTP_album_t *libmtpAlbum = LIBMTP_new_album_t();
-  libmtpAlbum->name = strdup([[album name] UTF8String]);
-  libmtpAlbum->artist = strdup([[track artist] UTF8String]);
-  libmtpAlbum->genre = strdup([[track genre] UTF8String]);
-  libmtpAlbum->album_id = [album albumID];
-  libmtpAlbum->no_tracks = size;
-  libmtpAlbum->tracks = trackArray;
+  LIBMTP_album_t *libmtpAlbum = [album toLIBMTPAlbum:track];
 	
   int playlistState = [album state];
   [album setState:NJB_PL_UNCHANGED];
@@ -2199,10 +2243,57 @@ int mtp_progress(uint64_t const sent, uint64_t const total, void const * const d
   return album;
 }
 
-- (NJBTransactionResult *)uploadAlbumArt:(NSString *)filename forTrack:(Track *)track
-{
-  // be sure of thread safety
-  /*
+- (NJBTransactionResult *)uploadAlbumArt:(NSBitmapImageRep *)imageRep forAlbum:(Album *)album
+{ 
+  if (album == nil)
+    return [[[NJBTransactionResult alloc] initWithSuccess:NO resultString:@"Cannot upload album art for nil album"] autorelease];
+    
+  if (imageRep == nil)
+    return [[[NJBTransactionResult alloc] initWithSuccess:YES] autorelease];
+  
+  NSImage *image = [[NSImage alloc] init];
+  [image addRepresentation:imageRep];
+  NSSize size;
+  size.width = 100;
+  size.height = 100;
+  NSImage *scaledImage = [image imageByScalingProportionallyToSize:size];
+  NSDictionary *properties = [NSDictionary dictionaryWithObject:[NSNumber numberWithFloat:0.9] forKey:NSImageCompressionFactor];
+  NSBitmapImageRep *bitmapImageRepScaled = [NSBitmapImageRep imageRepWithData:[scaledImage TIFFRepresentation]];
+  NSData *data = [bitmapImageRepScaled representationUsingType:NSJPEGFileType properties:properties];
+  if (data == nil)
+  {
+    NSLog(@"nil data in album art");
+    return [[[NJBTransactionResult alloc] initWithSuccess:YES] autorelease];
+  }
+  const char *bytes = [data bytes];
+  
+  LIBMTP_filesampledata_t sampledata;
+  sampledata.data = (char *)bytes;
+  sampledata.size = [data length];
+  NSLog(@"Sending album art of %d bytes", sampledata.size);
+  sampledata.duration = 0;
+  sampledata.filetype = LIBMTP_FILETYPE_JPEG;
+  sampledata.height = size.height;
+  sampledata.width = size.width;
+  
+  int ret = LIBMTP_Send_Representative_Sample(device, [album albumID], &sampledata);
+  
+  [image release];
+    
+  if (ret != 0)
+  {
+    NSString *error = @"Could not send representative sample data";
+    NSLog(error);
+    NSString *errorString = [self njbErrorString];
+    NSLog(errorString);
+    return [[[NJBTransactionResult alloc] initWithSuccess:NO resultString:error extendedErrorString:errorString] autorelease];
+  }
+  
+  return [[[NJBTransactionResult alloc] initWithSuccess:YES] autorelease];
+}
+
+- (NJBTransactionResult *)uploadAlbumArtForTrack:(Track *)track
+{   
   NSString *albumName = [track album];
   
   // don't add to a blank album
@@ -2235,29 +2326,7 @@ int mtp_progress(uint64_t const sent, uint64_t const total, void const * const d
       return [[[NJBTransactionResult alloc] initWithSuccess:NO resultString:@"Could not add track to album"] autorelease];
   }
   
-  // TODO: worry about thread safety of file stuff
-  NSFileHandle *file = [NSFileHandle fileHandleForReadingAtPath:filename];
-  NSData *data = [file readDataToEndOfFile];
-  const char *bytes = [data bytes];
-  
-  LIBMTP_filesampledata_t sampledata;
-  sampledata.data = (char *)bytes;
-  sampledata.size = [data length];
-  
-  int ret = LIBMTP_Send_Representative_Sample(device, [album albumID], &sampledata);
-  
-  [file closeFile];
-  
-  if (ret != 0)
-  {
-    NSString *error = @"Could not send representative sample data";
-    NSLog(error);
-    NSString *errorString = [self njbErrorString];
-    NSLog(errorString);
-    return [[[NJBTransactionResult alloc] initWithSuccess:NO resultString:error extendedErrorString:errorString] autorelease];
-  }
-  */
-  return [[[NJBTransactionResult alloc] initWithSuccess:YES] autorelease];
+  return [self uploadAlbumArt:[track image] forAlbum:album];
 }
 
 - (void)setCreateAlbumFiles:(BOOL)newCreateAlbumFiles
@@ -2270,5 +2339,71 @@ int mtp_progress(uint64_t const sent, uint64_t const total, void const * const d
   cancelCurrentTransaction = YES;
 }
 
+@end
+
+// this is copied (as allowed) from http://theocacao.com/document.page/498
+@implementation NSImage (ProportionalScaling)
+
+- (NSImage*)imageByScalingProportionallyToSize:(NSSize)targetSize
+{
+  NSImage* sourceImage = self;
+  NSImage* newImage = nil;
+
+  if ([sourceImage isValid])
+  {
+    NSSize imageSize = [sourceImage size];
+    float width  = imageSize.width;
+    float height = imageSize.height;
+    
+    float targetWidth  = targetSize.width;
+    float targetHeight = targetSize.height;
+    
+    float scaleFactor  = 0.0;
+    float scaledWidth  = targetWidth;
+    float scaledHeight = targetHeight;
+    
+    NSPoint thumbnailPoint = NSZeroPoint;
+    
+    if ( NSEqualSizes( imageSize, targetSize ) == NO )
+    {
+    
+      float widthFactor  = targetWidth / width;
+      float heightFactor = targetHeight / height;
+      
+      if ( widthFactor < heightFactor )
+        scaleFactor = widthFactor;
+      else
+        scaleFactor = heightFactor;
+      
+      scaledWidth  = width  * scaleFactor;
+      scaledHeight = height * scaleFactor;
+      
+      if ( widthFactor < heightFactor )
+        thumbnailPoint.y = (targetHeight - scaledHeight) * 0.5;
+      
+      else if ( widthFactor > heightFactor )
+        thumbnailPoint.x = (targetWidth - scaledWidth) * 0.5;
+    }
+    
+    newImage = [[NSImage alloc] initWithSize:targetSize];
+    
+    [newImage lockFocus];
+    
+      NSRect thumbnailRect;
+      thumbnailRect.origin = thumbnailPoint;
+      thumbnailRect.size.width = scaledWidth;
+      thumbnailRect.size.height = scaledHeight;
+      
+      [sourceImage drawInRect: thumbnailRect
+                     fromRect: NSZeroRect
+                    operation: NSCompositeSourceOver
+                     fraction: 1.0];
+    
+    [newImage unlockFocus];
+  
+  }
+  
+  return [newImage autorelease];
+}
 
 @end
