@@ -61,5 +61,7 @@
 - (void)setDownloadDir:(NSString *)downloadDir;
 - (NSString *)iTunesMusicLibraryLocation;
 - (void)setiTunesMusicLibraryLocation:(NSString *)iTunesMusicLibraryLocation;
+- (BOOL)createAlbumFiles;
+- (void)setCreateAlbumFiles:(BOOL)createAlbumFiles;
 
 @end
