@@ -127,6 +127,8 @@
 	// show these anyway
 	[downloadedTrackDir setStringValue:[preferences downloadDir]];
 	[iTunesMusicLibraryLocation setStringValue:[preferences iTunesMusicLibraryLocation]];
+  
+  [self setStateForButton:createAlbumFiles fromBool:[preferences createAlbumFiles]];
 	
 	// start with no changes
 	// this goes at the end as setting text above causes boxes to call controlTextDidChange
@@ -208,6 +210,8 @@
 	{
 		[preferences setiTunesIntegration:NO];
 	}
+  
+  [preferences setCreateAlbumFiles:[self boolForButton:createAlbumFiles]];
 	
 	[self close];
 }
@@ -380,6 +384,11 @@
 	isDirty = YES;
 }
 
+- (IBAction)createAlbumFiles:(id)sender
+{
+	isDirty = YES;
+}
+
 - (BOOL)isDirty
 {
 	if (isDirty)
