@@ -20,6 +20,7 @@
 	unsigned trackNumber;
 	unsigned year;
 	unsigned long long filesize;
+  NSBitmapImageRep *image;
 }
 - (id)initWithTrack:(Track *)track;
 - (NSString *)title;
@@ -47,6 +48,8 @@
 - (void)setFilesize:(unsigned long long)newFilesize;
 - (void)setValuesToTrack:(Track *)track;
 - (void)fileTypeFromExtension;
+- (void)setImage:(NSBitmapImageRep *)newImage;
+- (NSBitmapImageRep *)image;
 
 - (NSComparisonResult)compareByLength:(Track *)other;
 - (NSComparisonResult)compareUnsignedInts:(unsigned)mine withOther:(unsigned)theirs;
