@@ -52,6 +52,7 @@
 	[genre release];
   [filename release];
   [fullPath release];
+  [image release];
 	[super dealloc];
 }
 
@@ -235,6 +236,7 @@
 	[self setLength:[track length]];
 	[self setFileType:[track fileType]];
 	[self setItemID:[track itemID]];
+  [self setImage:[track image]];
 }
 
 - (NSString *)description
@@ -291,4 +293,16 @@
 	[self fileTypeFromExtension:fullPath];
 }
 
+- (void)setImage:(NSBitmapImageRep *)newImage
+{
+  [newImage retain];
+  [image release];
+  image = newImage;
+}
+
+- (NSBitmapImageRep *)image;
+{
+  return image;
+}
+
 @end
