@@ -58,6 +58,8 @@
 #define DEFAULT_PREF_KEY_DOWNLOAD_DIR @"~/Music/XNJB/"
 #define PREF_KEY_ITUNES_LOCATION @"iTunesLocation"
 #define DEFAULT_PREF_KEY_ITUNES_LOCATION @"~/Music/iTunes/iTunes Music Library.xml"
+#define PREF_KEY_CREATE_ALBUM_FILES @"createAlbumFiles"
+#define DEFAULT_PREF_KEY_CREATE_ALBUM_FILES [NSNumber numberWithBool:YES]
 
 // Notifications
 #define NOTIFICATION_CONNECTED @"XNJBConnected"
