@@ -5,18 +5,8 @@
 //  Created by Chris Drew on Thu Jan 16 2003.
 //  Copyright (c) 2003 __MyCompanyName__. All rights reserved.
 //
-
-#ifdef __APPLE__
 #import <Foundation/Foundation.h>
 #import "id3V2Frame.h"
-#else
-#ifndef _ID3FRAMEWORK_V20FRAMESET_H_
-#define _ID3FRAMEWORK_V20FRAMESET_H_
-#include "id3V2Frame.h"
-#include <Foundation/NSObject.h>
-@class NSMutableDictionary;
-#endif
-#endif
 
 #define MAXUNCOMPRESSEDFRAMESIZE 10000000
 
